@@ -1,7 +1,6 @@
 from hdsr_wis_config_reader import validation_rules
 from hdsr_wis_config_reader.idmappings.collection import IdMappingCollection
 from hdsr_wis_config_reader.location_sets.collection import LocationSetCollection
-from hdsr_wis_config_reader.location_sets.location_mapper import LocationMapper
 from hdsr_wis_config_reader.readers.config_reader import FewsConfigReader
 from hdsr_wis_config_reader.readers.xml_reader import XmlReader
 from hdsr_wis_config_reader.startenddate import merge_startenddate_github_with_idmap
@@ -12,7 +11,6 @@ from hdsr_wis_config_reader.startenddate import merge_startenddate_idmap
 validation_rules = validation_rules
 IdMappingCollection = IdMappingCollection
 LocationSetCollection = LocationSetCollection
-LocationMapper = LocationMapper
 FewsConfigReader = FewsConfigReader
 XmlReader = XmlReader
 merge_startenddate_idmap = merge_startenddate_idmap
