@@ -21,7 +21,7 @@ GITHUB_WIS_CONFIG_BRANCH_NAME = "202002-prd"
 # Github startendate repo
 GITHUB_STARTENDDATE_REPO_NAME = "startenddate"
 GITHUB_STARTENDDATE_BRANCH_NAME = "main"
-GITHUB_STARTENDDATE_ALLOWED_PERIOD_NO_UPDATES = timedelta(weeks=52 / 4)
+GITHUB_STARTENDDATE_ALLOWED_PERIOD_NO_UPDATES = timedelta(weeks=52)
 GITHUB_STARTENDDATE_CAW_OPPERVLAKTEWATER_SHORT = Path("data/output/results/caw_oppervlaktewater_short.csv")
 GITHUB_STARTENDDATE_CAW_OPPERVLAKTEWATER_LONG = Path("data/output/results/caw_oppervlaktewater_long.csv")
 GITHUB_STARTENDDATE_CAW_OPPERVLAKTEWATER_HYMOS_SHORT = Path("data/output/results/caw_oppervlaktewater_hymos_short.csv")
