@@ -346,6 +346,6 @@ def test_waterstandlocationset(loc_sets):
     assert loc_sets.waterstand_loc.validation_rules == expected_validation_rules
     assert loc_sets.waterstand_loc.csv_file_meta == expected_csvfile_meta
     assert loc_sets.waterstand_loc.attrib_files == expected_attrib_files
-    assert isinstance(loc_sets.waterstand_loc.geo_df, pd.DataFrame)
-    assert LocSetSharedCols.z in loc_sets.waterstand_loc.geo_df
-    assert not loc_sets.waterstand_loc.geo_df[LocSetSharedCols.z].hasnans
+    assert isinstance(loc_sets.waterstand_loc.geo_df_original, pd.DataFrame)
+    assert LocSetSharedCols.z in loc_sets.waterstand_loc.geo_df_original
+    assert not loc_sets.waterstand_loc.geo_df_original[LocSetSharedCols.z].hasnans
