@@ -18,12 +18,14 @@ class PdReadFlexibleCsv:
         expected_columns: List[str] = None,
         parse_dates: List[str] = None,
     ):
+        self.is_http_file = None
+        self.used_separator = None
+        self.used_encoding = None
         self.path_str = self._get_path(path=path)
         self.date_columns = parse_dates
-        self.separators = self._get_separators(sep=sep)
+        self.separators = self.__get_separators(sep=sep)
         self.expected_columns = expected_columns
-        self.df = self._get_df()
-        self.is_http_file = None
+        self._df = None
 
     def _get_path(self, path: Union[str, Path]) -> str:
         if isinstance(path, str) and ("http" in path or Path(path).is_file()):
@@ -37,16 +39,17 @@ class PdReadFlexibleCsv:
             "In case you use e.g. GithubFileDownloader, then use get_download_url() instead of target_file"
         )
 
-    def _get_separators(self, sep: str = None) -> List[str]:
+    @staticmethod
+    def __get_separators(sep: str = None) -> List[str]:
         if sep:
             assert isinstance(sep, str), f"sep {sep} must be of type string"
             return [sep]
-        if self.date_columns:
-            return [None, ";"]
+        # if self.date_columns:
+        #     return [None, ";"]
         return [",", ";"]
 
     @staticmethod
-    def _trim_all_string_columns(df):
+    def __trim_all_string_columns(df):
         """Trim whitespace from ends of each value across all series in dataframe."""
         return df.applymap(lambda x: x.strip() if isinstance(x, str) else x)
 
@@ -61,7 +64,7 @@ class PdReadFlexibleCsv:
                 if nr_separators_found != nr_expected_separators_per_row:
                     raise AssertionError(
                         f"csv error in {self.path_str} as line nr {index+1} has unexpected nr separators "
-                        f"{nr_separators_found} (expected={nr_expected_separators_per_row}"
+                        f"{nr_separators_found} (expected={nr_expected_separators_per_row})"
                     )
 
     @staticmethod
@@ -102,25 +105,30 @@ class PdReadFlexibleCsv:
                     err = f"row(s) {row_indices} contain empty cell(s) AND a separator other than {used_separator}"
                     raise AssertionError(f"{default_error_msg}, err={err}")
 
-    def _get_df(self) -> pd.DataFrame:
+    @property
+    def df(self) -> pd.DataFrame:
+        if self._df is not None:
+            return self._df
         default_error_msg = (
             f"could not read csv {self.path_str} with separators={self.separators}, "
             f"expected columns={self.expected_columns}"
         )
         for separator in self.separators:
             df = self._csv_to_df(separator=separator)
-            if df.empty:
-                continue
             if len(df.columns) == 1:
                 continue
+            if df.empty and len(df.columns) in (0, 1):
+                continue
             if self.expected_columns:
                 for expected_column in self.expected_columns:
                     assert (
                         expected_column in df.columns
                     ), f"expected_column {expected_column} must be in {df.columns}, file={self.path_str}"
-            df = self._trim_all_string_columns(df=df)
+            df = self.__trim_all_string_columns(df=df)
             self.__check_separators_per_row(used_separator=separator, df=df)
-            return df
+            self.used_separator = separator
+            self._df = df
+            return self._df
         raise AssertionError(default_error_msg)  # raise since no success
 
     def _csv_to_df(self, separator: str, encoding: str = None) -> pd.DataFrame:
@@ -131,10 +139,17 @@ class PdReadFlexibleCsv:
                 # convert 'None' to pd.NaN (we require this for the __check_sep_not_in_other_columns()
                 for date_column in self.date_columns:
                     df[date_column] = pd.to_datetime(arg=df[date_column], errors="coerce")
+            self.used_encoding = encoding
             return df
+        except pd.errors.EmptyDataError:
+            logger.warning(f"{self.path_str} is empty")
+            return pd.DataFrame(data=None)
         except pd.errors.ParserError as err:
             logger.debug(f"could not parse csv {self.path_str} with separator {separator}, err={err}")
             return pd.DataFrame(data=None)
+        except KeyError as err:
+            logger.debug(f"could not parse csv {self.path_str} with separator {separator}, err={err}")
+            return pd.DataFrame(data=None)
         except UnicodeDecodeError as err:
             with open(self.path_str) as tmp_file:
                 df = self._csv_to_df(separator=separator, encoding=tmp_file.encoding)
@@ -142,6 +157,7 @@ class PdReadFlexibleCsv:
                     logger.warning(
                         f"found encoding {tmp_file.encoding} (instead of utf-8) for {self.path_str}, err={err}"
                     )
+                self.used_encoding = tmp_file.encoding
                 return df
         except Exception as err:
             raise AssertionError(f"unexpected error when opening {self.path_str}, err={err}")
@@ -170,7 +186,7 @@ class DataframeActions:
 
     @classmethod
     def is_equal_dataframes(
-        cls, df1: pd.DataFrame, df2: pd.DataFrame, do_raise: bool = True, check_index: bool = True
+        cls, df1: pd.DataFrame, df2: pd.DataFrame, do_raise: bool = True, check_index: bool = False
     ) -> bool:
         assert isinstance(df1, pd.DataFrame) and isinstance(df2, pd.DataFrame)
         # ensure ordered dfs (index and column)
